@@ -9,9 +9,9 @@ with 'Org::ElementRole';
 with 'Org::ElementRole::Block';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-12'; # DATE
+our $DATE = '2023-08-05'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.559'; # VERSION
+our $VERSION = '0.560'; # VERSION
 
 has name => (is => 'rw');
 has properties => (is => 'rw');
@@ -22,7 +22,7 @@ sub BUILD {
     my $pass = $args->{pass} // 1;
 
     if ($pass == 2) {
-        die "Unknown drawer name: ".$self->name
+        $self->die("Unknown drawer name: ".$self->name)
             unless grep { $_ eq $self->name } @{$doc->drawer_names};
     }
 }
@@ -59,7 +59,7 @@ Org::Element::Drawer - Represent Org drawer
 
 =head1 VERSION
 
-This document describes version 0.559 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2023-07-12.
+This document describes version 0.560 of Org::Element::Drawer (from Perl distribution Org-Parser), released on 2023-08-05.
 
 =head1 DESCRIPTION
 
